SharedPrefsReviewGateStore class
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getEventCounts(
) → Future< Map< String, int> > -
override
-
getInstallAt(
) → Future< DateTime?> -
override
-
getLastAskedAt(
) → Future< DateTime?> -
override
-
getLastOutcome(
) → Future< String?> -
override
-
getSessionCount(
) → Future< int> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setEventCounts(
Map< String, int> map) → Future<void> -
override
-
setInstallAt(
DateTime dt) → Future< void> -
override
-
setLastAskedAt(
DateTime dt) → Future< void> -
override
-
setLastOutcome(
String v) → Future< void> -
override
-
setSessionCount(
int v) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited